==> trash-3.0.0.tar.gz: trash/src/Form/TrashSettingsForm.php <==
<?php

namespace Drupal\trash\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\Sql\SqlEntityStorageInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Validation;

/**
 * Configure Trash settings for this site.
 */
class TrashSettingsForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * Constructs a PathautoSettingsForm.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Defines the configuration object factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Manages entity type plugin definitions.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   Manages the discovery of entity fields.
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityTypeManagerInterface $entity_type_manager, EntityFieldManagerInterface $entity_field_manager) {
    parent::__construct($config_factory);
    $this->entityTypeManager = $entity_type_manager;
    $this->entityFieldManager = $entity_field_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager'));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'trash_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['trash.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('trash.settings');

    $form['enabled_entity_types'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#title' => $this->t('Enabled entity types'),
      '#tree' => TRUE,
    ];

    // Disallow enabling trash on entity types that haven't been tested enough.
    $disallowed_entity_types = [
      'block_content',
      'comment',
      'taxonomy_term',
      'path_alias',
      'user',
      'workspace',
      'wse_menu_tree',
    ];

    if ($this->entityTypeManager->hasDefinition('menu_link_content')) {
      // Custom menu links can be deleted if there's a module which allows
      // changing the hierarchy in pending revisions (e.g. wse_menu).
      $menu_link_content = $this->entityTypeManager->getDefinition('menu_link_content');
      $constraints = $menu_link_content->getConstraints();
      if (isset($constraints['MenuTreeHierarchy'])) {
        $disallowed_entity_types = array_merge($disallowed_entity_types, ['menu_link_content']);
      }
    }
    // Get all applicable entity types.
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if (is_subclass_of($entity_type->getStorageClass(), SqlEntityStorageInterface::class)
        && !\in_array($entity_type_id, $disallowed_entity_types, TRUE)) {
        $field_definitions = $this->entityFieldManager->getBaseFieldDefinitions($entity_type_id);
        $form['enabled_entity_types'][$entity_type_id] = [
          '#type' => 'checkbox',
          '#title' => $entity_type->getLabel(),
          '#default_value' => isset($field_definitions['deleted']) && in_array($entity_type_id, $config->get('enabled_entity_types')),
          '#disabled' => isset($field_definitions['deleted']) && ($field_definitions['deleted']->getProvider() !== 'trash'),
        ];
      }
    }

    $form['auto_purge'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#title' => $this->t('Auto-purge settings'),
      '#tree' => TRUE,
    ];
    $form['auto_purge']['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable auto-purge'),
      '#description' => $this->t('Beware: this will permanently delete entities in the trash bin after the configured time period.'),
      '#default_value' => $config->get('auto_purge.enabled'),
    ];
    $form['auto_purge']['after'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Auto-purge after entities have been in the trash bin for longer than this time'),
      '#description' => $this->t("The time period should be specified as '30 days', '15 days, 12 hours', etc."),
      '#default_value' => $config->get('auto_purge.after'),
      '#config_target' => 'trash.settings:auto_purge.after',
      '#states' => [
        'visible' => [
          ':input[name="auto_purge[enabled]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    // @todo Remove this validations when we can drop support for core < 10.2.
    parent::validateForm($form, $form_state);
    $value = $form_state->getValue(['auto_purge', 'after']);
    if ($value !== NULL) {
      $validator = Validation::createValidatorBuilder()->getValidator();
      $constraint_manager = \Drupal::typedDataManager()->getValidationConstraintManager();
      $constraint = $constraint_manager->create('ValidAutoPurgePeriod', []);
      $violations = $validator->validate($value, [$constraint]);
      if ($violations->count() > 0) {
        $form_state->setErrorByName('auto_purge][after', $violations->get(0)->getMessage());
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('trash.settings');
    $form_state->cleanValues();

    foreach ($form_state->getValues() as $key => $value) {
      if ($key == 'enabled_entity_types') {
        $enabled_entity_types = [];
        foreach ($value as $entity_type_id => $enabled) {
          $field_definitions = $this->entityFieldManager->getBaseFieldDefinitions($entity_type_id);
          // Verify that the entity type is enabled and that it is not defined
          // or defined by us before adding it to the configuration, so that
          // we do not store an entity type that cannot be enabled or disabled.
          if ($enabled && (!isset($field_definitions['deleted']) || ($field_definitions['deleted']->getProvider() === 'trash'))) {
            $enabled_entity_types[] = $entity_type_id;
          }
        }
        $value = $enabled_entity_types;
      }
      $config->set($key, $value);
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}

==> trash-3.0.3.tar.gz: trash/src/Form/TrashSettingsForm.php <==
<?php

namespace Drupal\trash\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\Sql\SqlEntityStorageInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\TypedDataTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Validation;

/**
 * Configure Trash settings for this site.
 */
class TrashSettingsForm extends ConfigFormBase {

  use TypedDataTrait;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * Constructs a PathautoSettingsForm.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Defines the configuration object factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Manages entity type plugin definitions.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   Manages the discovery of entity fields.
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityTypeManagerInterface $entity_type_manager, EntityFieldManagerInterface $entity_field_manager) {
    parent::__construct($config_factory);
    $this->entityTypeManager = $entity_type_manager;
    $this->entityFieldManager = $entity_field_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager'));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'trash_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['trash.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('trash.settings');

    $form['enabled_entity_types'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#title' => $this->t('Enabled entity types'),
      '#tree' => TRUE,
    ];

    // Disallow enabling trash on entity types that haven't been tested enough.
    $disallowed_entity_types = [
      'block_content',
      'comment',
      'taxonomy_term',
      'path_alias',
      'user',
      'workspace',
      'wse_menu_tree',
    ];

    if ($this->entityTypeManager->hasDefinition('menu_link_content')) {
      // Custom menu links can be deleted if there's a module which allows
      // changing the hierarchy in pending revisions (e.g. wse_menu).
      $menu_link_content = $this->entityTypeManager->getDefinition('menu_link_content');
      $constraints = $menu_link_content->getConstraints();
      if (isset($constraints['MenuTreeHierarchy'])) {
        $disallowed_entity_types = array_merge($disallowed_entity_types, ['menu_link_content']);
      }
    }
    // Get all applicable entity types.
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if (is_subclass_of($entity_type->getStorageClass(), SqlEntityStorageInterface::class)
        && !\in_array($entity_type_id, $disallowed_entity_types, TRUE)) {
        $field_definitions = $this->entityFieldManager->getBaseFieldDefinitions($entity_type_id);
        $form['enabled_entity_types'][$entity_type_id] = [
          '#type' => 'checkbox',
          '#title' => $entity_type->getLabel(),
          '#default_value' => isset($field_definitions['deleted']) && in_array($entity_type_id, $config->get('enabled_entity_types')),
          '#disabled' => isset($field_definitions['deleted']) && ($field_definitions['deleted']->getProvider() !== 'trash'),
        ];
      }
    }

    $form['auto_purge'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#title' => $this->t('Auto-purge settings'),
      '#tree' => TRUE,
    ];
    $form['auto_purge']['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable auto-purge'),
      '#description' => $this->t('Beware: this will permanently delete entities in the trash bin after the configured time period.'),
      '#default_value' => $config->get('auto_purge.enabled'),
    ];
    $form['auto_purge']['after'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Auto-purge after entities have been in the trash bin for longer than this time'),
      '#description' => $this->t("The time period should be specified as '30 days', '15 days, 12 hours', etc."),
      '#default_value' => $config->get('auto_purge.after'),
      '#config_target' => 'trash.settings:auto_purge.after',
      '#states' => [
        'visible' => [
          ':input[name="auto_purge[enabled]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    // @todo Remove this validations when we can drop support for core < 10.2.
    parent::validateForm($form, $form_state);
    $value = $form_state->getValue(['auto_purge', 'after']);
    if ($value !== NULL) {
      $validator = Validation::createValidatorBuilder()->getValidator();
      $constraint_manager = $this->getTypedDataManager()->getValidationConstraintManager();
      $constraint = $constraint_manager->create('ValidAutoPurgePeriod', []);
      $violations = $validator->validate($value, [$constraint]);
      if ($violations->count() > 0) {
        $form_state->setErrorByName('auto_purge][after', $violations->get(0)->getMessage());
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('trash.settings');
    $form_state->cleanValues();

    foreach ($form_state->getValues() as $key => $value) {
      if ($key == 'enabled_entity_types') {
        $enabled_entity_types = [];
        foreach ($value as $entity_type_id => $enabled) {
          $field_definitions = $this->entityFieldManager->getBaseFieldDefinitions($entity_type_id);
          // Verify that the entity type is enabled and that it is not defined
          // or defined by us before adding it to the configuration, so that
          // we do not store an entity type that cannot be enabled or disabled.
          if ($enabled && (!isset($field_definitions['deleted']) || ($field_definitions['deleted']->getProvider() === 'trash'))) {
            $enabled_entity_types[] = $entity_type_id;
          }
        }
        $value = $enabled_entity_types;
      }
      $config->set($key, $value);
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
